Module logging

Module logging 

Shared logging initialization for Robit binaries.

Provides a unified way to initialize logging with support for:

  • Config file app.log_level setting
  • Config file app.log_file setting (log to file, daily rotation)
  • Environment variable RUST_LOG (takes precedence)
  • Sensible defaults for third-party crates

Functions

init_logging
Initialize logging with optional app config and a target crate name.
init_logging_silent
Initialize logging but discard output (for TUI mode).