pub struct ChatCompletionRequestAssistantMessage {
pub content: Option<ChatCompletionRequestAssistantMessageContent>,
pub refusal: Option<String>,
pub name: Option<String>,
pub audio: Option<ChatCompletionRequestAssistantMessageAudio>,
pub tool_calls: Option<Vec<ChatCompletionMessageToolCalls>>,
pub function_call: Option<FunctionCall>,
}Fields
content: Option<ChatCompletionRequestAssistantMessageContent>The contents of the assistant message. Required unless tool_calls or function_call is specified.
refusal: Option<String>The refusal message by the assistant.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.
audio: Option<ChatCompletionRequestAssistantMessageAudio>Data about a previous audio response from the model. Learn more.
tool_calls: Option<Vec<ChatCompletionMessageToolCalls>>function_call: Option<FunctionCall>👎Deprecated
Deprecated and replaced by tool_calls. The name and arguments of a function that should be called, as generated by the model.