Shared logging initialization for Robit binaries.
Provides a unified way to initialize logging with support for:
- Config file
app.log_levelsetting - Config file
app.log_filesetting (log to file, daily rotation) - Environment variable
RUST_LOG(takes precedence) - Sensible defaults for third-party crates
Functions
- init_
logging - Initialize logging with optional app config and a target crate name.
- init_
logging_ silent - Initialize logging but discard output (for TUI mode).